/*--- (c) 2002 iWombat.com All rights reserved ---*/

package com.iwombat.foundation.environment;

import java.util.Properties;
import java.io.*;
import java.io.IOException;
import java.net.*;

/**
 * A singleton to contain envoronment properties useful to frameworks and services
 *
 * @author  $Author: bob $
 * @version $Revision: 1.6 $
 * <br>
 * <dl><dt><b>Date:</b><dd>$Date: 2003/10/08 17:25:28 $</dd></dl>
 */
public class EnvironmentProperties {

    public static final String  ENV_BOOTSTRAP_URL = "ENV_PROPFILE";
    public static final String  ENVIRONMENT_PROPERTY_FILE = "environment.properties";
    public static final String  CONFIGURATION_BASE_URL = "configBaseURL";


    private static EnvironmentProperties singleton = new EnvironmentProperties();
    private Properties props = null;
    
    // grab the properties from our system property file
    private void init() {
	if (null == props) {        
        try {
            props = new Properties();
 
	    	String bootstrap =  System.getProperty(ENV_BOOTSTRAP_URL);
	    	InputStream in = null;
	    	if (null == bootstrap) { 
				System.out.println("Initializing environment via Class Loader");
            	in = EnvironmentProperties.class.getClassLoader().getResourceAsStream(ENVIRONMENT_PROPERTY_FILE);
            } else {
				System.out.println("Initializing environment via Environment Bootstrap");
				try {
					URL newURL = new URL(bootstrap);
					URLConnection conn = newURL.openConnection();
					in = conn.getInputStream();
				} catch (IOException e) {
					System.out.println("Unable to load environment properties from URL: " + bootstrap);
					throw e;
				}
	    	}

            props.load(in);
            in.close();
                       
        // this is pretty drastic, but what else would one do?
        } catch (IOException e) {
            System.out.println("Failed to load startup properties aborting execution:" + e.getMessage());
//          	throw e;
        }
	}
        
    }

    private synchronized static void initCheck() {
	if (null == singleton) {
		singleton = new EnvironmentProperties();
	}
    }
    
    /** enforce singleton-ism */
    private EnvironmentProperties() {
    	init();
    }
    
    protected String getMyProperty(String key) {
	this.init();
    	return this.props.getProperty(key);
    }

    /**
     * Get a property for a key. Should use the public statics for key lookup
     *
     */
    public static String getProperty(String key) {
	initCheck();
        return singleton.getMyProperty(key);
    }
    
    
    
    protected Properties getMyProperties() {
	this.init();
    	return this.props;
    }
    /**
     * Get the internal store of cached properties. This is very useful for
     * testing environments
     *
     */
    public static Properties getProperties() {
	initCheck();
        return singleton.getMyProperties();
    }
    
    
    protected synchronized void setMyProperties(Properties newProps) {
    	this.props = newProps;
    }
    
    /**
     * Get the internal store of cached properties. Used in conjunction with
     * getProperties this is very useful for testing environments
     *
     */
    public static void setProperties(Properties newProps) {
	initCheck();
       singleton.setMyProperties(newProps);
    }
}
