// (c) Copyright 2001-2002 iwombat.com all rights reserved
package com.iwombat.foundation.persist;

/**
 * Class BeanToSqlParameterMapper
 * Description: Maps a bean property to a sql prepared statement parameter
 *
 * @author  $Author: brentp $
 * @version $Revision: 1.1 $
 * 
 * <br>
 * <dl><dt><b>Date:</b><dd>$Date: 2002/11/18 16:04:39 $</dd></dl>
 */
import java.sql.*;

import com.iwombat.util.ByteArray;

import com.iwombat.foundation.Identifier;

public interface BeanToSqlParameterMapper {

    /**
     * sets the source Bean where bean property values will be retrieved for mapping operations
     *
     * @param the source Bean to set
     */
    public void setSourceBean(Object sourceBean);
    
    /**
     * retrieves the currently set source Bean where bean property values will be retrieved for mapping operations
     *
     * @return the currently set source Bean
     */
    public Object getSourceBean();
    
    /**
     * sets the target prepared statement where sql parameter values will be written into for mapping operations
     *
     * @param the prepared statement to set
     */
    public void setTargetPreparedStatement(PreparedStatement targetPreparedStatement);
    
    /**
     * retrieves the currently set target prepared statement where sql parameter values will be written into for mapping operations
     * 
     * @return the currently set prepared statement
     */
    public PreparedStatement getTargetPreparedStatement();
    
    /**
     * writes a parameter value into the currently set target prepared statement from the currently set source Bean,
     * according to the specified parameter to Bean map configuration
     *
     * @param the parameter to Bean map configuration to use for this operation
     */
    public void writeParameterValue(OrdinalParameterToBeanMapItem paramToBeanConfig);
   
    /**
     * writes a ByteArray parameter into the currently set target prepared statement from the currently set source Bean
     *
     * @param the ByteArray value to set
     * @param the parameter index to use on the target prepared statement
     */
    public void writeByteArrayParameter(ByteArray byteArrayValue, int parameterIndex) throws SQLException;

    /**
     * writes a String parameter into the currently set target prepared statement from the currently set source Bean
     *
     * @param the String value to set
     * @param the parameter index to use on the target prepared statement
     */
    public void writeStringParameter(String stringValue,  int parameterIndex) throws SQLException;

    /**
     * writes a Float parameter into the currently set target prepared statement from the currently set source Bean
     *
     * @param the Float value to set
     * @param the parameter index to use on the target prepared statement
     */
    public void writeFloatParameter(Float floatValue, int parameterIndex) throws SQLException;

    /**
     * writes a Boolean parameter into the currently set target prepared statement from the currently set source Bean
     *
     * @param the Boolean value to set
     * @param the parameter index to use on the target prepared statement
     */
    public void writeBooleanParameter(Boolean booleanValue,  int parameterIndex) throws SQLException;

    /**
     * writes a Long parameter into the currently set target prepared statement from the currently set source Bean
     *
     * @param the Long value to set
     * @param the parameter index to use on the target prepared statement
     */
    public void writeLongParameter(Long longValue,  int parameterIndex) throws SQLException;

    /**
     * writes an Identifier parameter into the currently set target prepared statement from the currently set source Bean
     *
     * @param the Identifier value to set
     * @param the parameter index to use on the target prepared statement
     */
    public void writeIdentifierParameter(Identifier identifierValue,  int parameterIndex) throws SQLException;

    /**
     * writes a Date parameter into the currently set target prepared statement from the currently set source Bean
     *
     * @param the Date value to set
     * @param the parameter index to use on the target prepared statement
     */
    public void writeDateParameter(java.util.Date dateValue,  int parameterIndex) throws SQLException;
}
