// (c) Copyright 2001-2002 iwombat.com all rights reserved
package com.iwombat.foundation.persist;

import java.sql.*;

import com.iwombat.foundation.Identifier;
/**
 * Bean to Sql Parameter mapper with Identifiers expressed as VARCHAR;
 * <br>
 * maps the following obect to sql data types:
 * <br><br>
 * java.lang.String = java.sql.Types.VARCHAR
 * <br>
 * <b>com.iwombat.Identifier = java.sql.Types.VARCHAR</b>
 * <br>
 * java.lang.Long = java.sql.Types.INTEGER
 * <br>
 * java.lang.Float = java.sql.Types.NUMERIC
 * <br>
 * java.lang.Boolean = java.sql.Types.TINYINT
 * <br>
 * com.iwombat.ByteArray = java.sql.Types.BINARY
 * <br>
 * java.util.Date = java.sql.Types.TIMESTAMP
 * <br>
 *
 * @author  $Author: brentp $
 * @version $Revision: 1.1 $
 * 
 * <br>
 * <dl><dt><b>Date:</b><dd>$Date: 2002/11/18 16:04:39 $</dd></dl>
 */
public class CharIdentifierBeanToSqlParameterMapper extends StandardBeanToSqlParameterMapper {
    
    /**
     * writes an Identifier value from the currently set source Bean into the currently set Prepared Statement for the
     * specified parameter index
     *
     * @param the Identifier value to set
     * @param the parameter index to write into
     */
    public void writeIdentifierParameter(Identifier identifierValue,  int parameterIndex) throws SQLException{
        
        PreparedStatement p = this.getTargetPreparedStatement();
        if (null==p) throw new IllegalStateException("target prepared statement is not defined");
        
        if (null==identifierValue){
            p.setNull(parameterIndex,java.sql.Types.VARCHAR);
        }
        else{
            p.setString(parameterIndex, identifierValue.toHexString());
        }
    }
    
}
