// (c) Copyright 2001-2002 iwombat.com all rights reserved
package com.iwombat.foundation.persist;

import com.iwombat.foundation.environment.*;

import com.iwombat.util.ObjectUtil;

/**
 * Class DAOFactory
 * Description: A factory that can create instances of DataAccessObjects based on a specified domain object interface.
 * <br><br>
 * The map is stored in a properties file, in the form of "domain_object_interface_class_name = data_access_object_interface_class_name".
 *
 * @author  $Author: brentp $
 * @version $Revision: 1.3 $
 * 
 * <br>
 * <dl><dt><b>Date:</b><dd>$Date: 2002/11/18 16:04:39 $</dd></dl>
 */

public class DAOFactory {
    
    /**
     * Creates an instance of a DataAccessObject and returns a DAO interface,
     * based on a mapping of the specified domain object class.<br>
     * The generated class must be cast-able into a Persistable interface.
     *
     * @param the Class for the target domain object (usually the domain object interface)
     * @return DAO interface
     */
    public static DAO createDAOInstance(Class domainObjectClass) throws PersistenceException{
        
        DAO dataAccessObjectInterface = null;
        String domainObjectClassName = domainObjectClass.getName();
        
        try{
            dataAccessObjectInterface=(DAO)ObjectUtil.createObjectFromConfig(PersistenceConstants.DAO_FACTORY_CONFIG, domainObjectClassName);
        }
        catch (Throwable t){
            throw new PersistenceConfigException("Unable to create DAO for domain object='" + domainObjectClassName + "'.",t);
        }
        
        return dataAccessObjectInterface;
    }


    /**
     * force singleton
     */
    private DAOFactory(){}
}
