// (c) Copyright 2001-2002 iwombat.com all rights reserved
package com.iwombat.foundation.persist;

import com.iwombat.foundation.environment.Configuration;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import javax.sql.PooledConnection;

/**
 * a sql persistence provider for the MySql relational database engine
 * <br><br>
 *
 * @author  $Author: brentp $
 * @version $Revision: 1.3 $
 * 
 * <br>
 * <dl><dt><b>Date:</b><dd>$Date: 2002/11/18 17:16:14 $</dd></dl>
 */

public class MysqlPersistence implements SqlPersistence,Configuration{
    
    private String hostname = null;
    private int portNumber=3306;
    private String databaseName = null;
    private String password = null;
    private String userId = null;
    private int initialPoolSize=1;
    private int maxPoolSize=1;
    private int minPoolSize=1;
    
    private String key;
    private String description;
    
    private static final String _sDriverClass="org.gjt.mm.mysql.Driver";
    
    private boolean driverLoaded=false;
    
    public MysqlPersistence() {
    }
    
    
    public void resetConnectionPool() {
        
    }
    
    protected String getDriverURL(){
        
        
        String hostname;
        String userId;
        String password;
        int portNumber;
        String databaseName;
        
        StringBuffer driverURL;
        
        hostname=getHostname();
        if (hostname==null) throw new PersistenceException("hostname is not defined");
        
        userId=getUserId();
        if (userId==null) throw new PersistenceException("userId is not defined");
        
        password=getPassword();
        if (password==null) throw new PersistenceException("password is not defined");
        
        databaseName=getDatabaseName();
        if (databaseName==null) throw new PersistenceException("database name is not defined");
        
        portNumber=getPortNumber();
        
        driverURL=new StringBuffer();
        
        driverURL.append("jdbc:mysql://");
        driverURL.append(hostname);
        driverURL.append(":");
        driverURL.append(portNumber);
        driverURL.append("/");
        driverURL.append(databaseName);
        driverURL.append("?user=");
        driverURL.append(userId);
        driverURL.append("&password=");
        driverURL.append(password);
        driverURL.append("&autoReconnect=true");
        
        return driverURL.toString();
        
    }
    
    public Connection getConnection() {
        
        
        try{
            Class.forName(_sDriverClass).newInstance();
        }
        catch (Throwable t){
            throw new PersistenceException("Unable to load the JDBC driver. " + t.getMessage());
        }
        
        try{
            
            return DriverManager.getConnection(getDriverURL());
            
        }
        catch(SQLException e){
            throw new PersistenceException("connection failed: " + e.getMessage());
        }
        
        
    }
    
    
    public String getDescription() {
        return this.description;
    }
    
    public void setDescription(String description) {
        this.description=description;
    }
    
    public String getKey() {
        return this.key;
    }
    
    public void setKey(String key) {
        this.key=key;
    }
    
    public int getPortNumber(){
        return this.portNumber;
    }
    
    public void setPortNumber(int portNumber){
        this.portNumber=portNumber;
    }
    
    
    public String getUserId() {
        return this.userId;
    }
    
    public void setUserId(String userId) {
        this.userId=userId;
    }
    
    public String getDatabaseName() {
        return this.databaseName;
    }
    
    public void setDatabaseName(String databaseName) {
        this.databaseName=databaseName;
    }
    
    public int getMinPoolSize() {
        return this.minPoolSize;
    }
    
    public void setMinPoolSize(int minPoolSize) {
        this.minPoolSize=minPoolSize;
    }
    
    
    
    public String getPassword() {
        return this.password;
    }
    
    public void setPassword(String password) {
        this.password=password;
    }
    
    public int getMaxPoolSize() {
        return this.maxPoolSize;
    }
    
    public void setMaxPoolSize(int maxPoolSize) {
        this.maxPoolSize=maxPoolSize;
    }
    
    public int getInitialPoolSize() {
        return this.initialPoolSize;
    }
    
    public void setInitialPoolSize(int initialPoolSize) {
        this.initialPoolSize=initialPoolSize;
    }
    
    public String getHostname() {
        return this.hostname;
    }
    
    public void setHostname(String hostname) {
        this.hostname=hostname;
    }
    
    /** retrieves the key name representing this persistence technology
     *
     * <br><br>
     *
     * @return the key representing this persistence technology
     *
     * @see com.iwombat.foundation.persist.PersistenceTechnologies
     */
    public String getPersistenceTechnologyKey() {
        
        return PersistenceTechnologies.MYSQL;
    }    
    
    
    
    
    
}
