// (c) Copyright 2001-2002 iwombat.com all rights reserved
package com.iwombat.foundation.persist;

import java.sql.Connection;
import java.sql.SQLException;

/**
 * Represents an instance of an Rdbms Transaction
 *
 * @author  $Author: brentp $
 * @version $Revision: 1.4 $
 * 
 * <br>
 * <dl><dt><b>Date:</b><dd>$Date: 2002/11/18 16:04:40 $</dd></dl>
 */

public class RdbmsTransactionInstance implements TransactionInstance{
    
    private Connection connection;
    
    /** Creates a new instance of RdbmsTransactionInstance 
     *
     * @param the connection object associated with this transaction
     */
    public RdbmsTransactionInstance(Connection connection) {
        this.setConnection(connection);
    }
    

    private void setConnection(Connection newConnection){
        
        try{
            if (newConnection!=null) newConnection.setAutoCommit(false);
        }
        catch (SQLException e){
            throw new PersistenceException("unable to disable auto commit on new Connection: " + e.getMessage());
        }
        this.connection=newConnection;
    }

    /**
     * retrieves the connection associated with this transaction
     *
     * @return the connection object
     */
    protected Connection getConnection(){
        return this.connection;
    }
    
    
    /**
     * aborts the current transaction
     *
     */
    public void abort() {
        
        Connection activeConnection=this.getConnection();

            if (activeConnection!=null){
                try{
                    activeConnection.close();
                }
                catch (java.sql.SQLException e){
                    throw new PersistenceException("Unable to abort transaction: SQL Execption caught: " + e.getMessage());
                }
                this.setConnection(null);
            }
    }
    
    /**
     * commits the current transaction
     */
    public void commit() {

        Connection activeConnection=this.getConnection();

            if (activeConnection!=null){
                try{
                    activeConnection.commit();
                    activeConnection.close();
                }
                catch (java.sql.SQLException e){
                    throw new PersistenceException("Unable to abort transaction: SQL Execption caught: " + e.getMessage());
                }
                this.setConnection(null);
            }
            else{
                throw new PersistenceException("Unable to commit transaction: No active connection!");
            }
    }

}
