/*--- (c) 2003 iWombat.com All rights reserved ---*/
package com.iwombat.swing;

import java.awt.Dimension;
import java.awt.Insets;

import javax.swing.DefaultDesktopManager;
import javax.swing.JComponent;
import javax.swing.JInternalFrame;
import javax.swing.JScrollPane;
import javax.swing.JViewport;

/**
 * Desktop manager for a MultiDocumentDesktopPane
 * 
 * @author  $Author: bob $
 * @version $Revision: 1.2 $
 * 
 * <br>
 * <dl><dt><b>Date:</b><dd>$Date: 2003/10/08 05:16:47 $</dd></dl>
*/

public class MultiDocumentDesktopManager extends DefaultDesktopManager {

    private MultiDocumentDesktopPane desktop = null;

    public MultiDocumentDesktopManager(MultiDocumentDesktopPane desktop) {
        this.desktop = desktop;
    }

    // private convienience methods
    private Insets getScrollPaneInsets() {
        JScrollPane pane = this.getScrollPane();
        if (null == pane) {
            return new Insets(0,0,0,0);
        } else {
            return pane.getBorder().getBorderInsets(pane);
        }
    }

    private JScrollPane getScrollPane() {
        if (desktop.getParent() instanceof JViewport) {
            JViewport viewPort = (JViewport)desktop.getParent();
            if (viewPort.getParent() instanceof JScrollPane) {
                return (JScrollPane)viewPort.getParent();
            }
        }
        return null;
    }
    
    
    // overide class methods

    public void endResizingFrame(JComponent frame) {
        super.endResizingFrame(frame);
        syncDesktopSize();
    }

    public void endDraggingFrame(JComponent frame) {
        super.endDraggingFrame(frame);
        syncDesktopSize();
    }

    /** 
     * This method sets the size of the desktop to the size the window can
     * naturally contain without scrollbars.
     *
     *
     */
    public void setNaturalSize() {        
        final int offset = 20;
        Insets insets = getScrollPaneInsets();
        JScrollPane pane = getScrollPane();
        
        if (null != pane) {
            double width = 0.0;
            double height = 0.0;
            Dimension dimension = pane.getVisibleRect().getSize();
            if ( null != pane.getBorder() ) {               
               width = dimension.getWidth() - insets.left - insets.right;
               height = dimension.getHeight() - insets.top - insets.bottom;
               dimension.setSize(width, height);
            }

            // now calculate the offsets
            width = dimension.getWidth() - offset;
            height = dimension.getHeight() - offset;
            dimension.setSize(width, height);
            
            desktop.setAllSize(0,0);
            pane.invalidate();
            pane.validate();
        }
    }

    /**
     * This method syncs the size of the desktop to contain all the windows
     * within.
     *
     */

    protected void syncDesktopSize() {
        
        JScrollPane pane = getScrollPane();
        Insets insets = getScrollPaneInsets();

        int xpos = 0;
        int ypos = 0;
        final int offset = 20;
        if (null != pane) {
            JInternalFrame frames[] = desktop.getAllFrames();
            for (int i=0; i< frames.length; i++) {
                int rightEdge = frames[i].getX() + frames[i].getWidth();
                if ( xpos < rightEdge ) {
                    xpos = rightEdge;
                }
                int bottomEdge = frames[i].getY() + frames[i].getHeight();
                if ( ypos < bottomEdge ) {
                    ypos = bottomEdge;
                }
            }
            Dimension dimension = pane.getVisibleRect().getSize();
            if (pane.getBorder() != null) {
               double width = dimension.getWidth() - insets.left - insets.right;
               double height = dimension.getHeight() - insets.top - insets.bottom;
               dimension.setSize(width, height);
            }

            if (xpos <= dimension.getWidth()) {
                xpos = (int)(dimension.getWidth() - offset);
            }
            if (ypos <= dimension.getHeight()) {
                ypos = (int)(dimension.getHeight() - offset);
            }
            desktop.setAllSize(xpos,ypos);
            pane.invalidate();
            pane.validate();
        }
    }
}